{% extends 'base.html' %}

{% block title %}Error{% endblock %}

{% block content %}
<div class="container">
    <h1 class="text-center text-danger">Error</h1>
    <p class="text-center lead">{{ message }}</p>
    <div class="text-center">
        <a href="/" class="btn btn-primary">Go Back to Home</a>
    </div>
</div>
{% endblock %}
