<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>{% block title %}RVTools Analyzer{% endblock %}</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha3/dist/css/bootstrap.min.css" rel="stylesheet">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css">
    <link rel="icon" type="image/png" href="/static/favicon.png">
    <style>
        body {
            background-color: #121212;
            color: #ffffff;
        }
        .container {
            margin-top: 50px;
            padding-left: 15px;
            padding-right: 15px;
        }
        .explore-content {
            max-width: 95%;
            margin-top: 50px;
        }

        .navbar {
            background-color: #1f1f1f;
        }
        .navbar a {
            color: #ffffff;
        }
        .chart-container {
            display: flex;
            justify-content: center;
            align-items: center;
            width: 100% !important;
            max-height: 500px;
        }

        @media print {
            .container {
                width: 100%;
                margin: 25px;
                padding: 0;
            }
            .card {
                page-break-inside: avoid;
            }
            .d-flex {
                flex-wrap: wrap;
                justify-content: space-between;
            }
            .btn, .navbar {
                display: none; /* Hide buttons during print */
            }
            .badge, .card-header, .card-footer {
                -webkit-print-color-adjust: exact; /* Ensure colors are printed */
                print-color-adjust: exact; /* Standard property for compatibility */
            }
            h1, .lead {
                color:#121212;
            }
        }
    </style>
</head>
<body>
    <nav class="navbar navbar-expand-lg navbar-dark">
        <div class="container-fluid">
            <a class="navbar-brand" href="/">RVTools Analyzer</a>
        </div>
    </nav>
    {% block content %}{% endblock %}
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha3/dist/js/bootstrap.bundle.min.js"></script>
    <footer class="text-center mt-4 footer">
        <p>Version: {{ calver_version }} | <a href="https://github.com/lrivallain/avs-rvtools-analyzer" target="_blank">GitHub Repository</a></p>
    </footer>
</body>
</html>